/**
 * Pyx4me framework
 * Copyright (C) 2006-2007 pyx4.com.
 * 
 * @author vlads
 * @version $Id: AbstractDeviceMojo.java 199 2007-08-02 20:35:39Z vlads $
 */
package com.pyx4me.maven.obex;

import org.apache.maven.plugin.AbstractMojo;
import org.apache.maven.plugin.MojoFailureException;
import org.apache.maven.plugin.logging.Log;
import org.apache.maven.settings.Server;
import org.apache.maven.settings.Settings;
import org.codehaus.plexus.util.xml.Xpp3Dom;

public abstract class AbstractDeviceMojo extends AbstractMojo {
	/**
     * The server id prefix in settings.xml to use when connecting.
     *
     * @parameter expression="${obex.server}" default-value="obex-device"
     * @required
     */
	protected String server = "obex-device";
 	
    /**
     * Specifies optional sufix for server ID to use.
     *
     * @parameter expression="${obex.c}"
     */
	protected String serverSufix;
	
    /**
     * The current user system settings for use in Maven.
     *
     * @parameter expression="${settings}"
     * @required
     * @readonly
     */
    protected Settings settings;
    
    private static boolean configured = false;
    
    protected ServerConfig getServerConfig(String serverSufix) throws MojoFailureException {
    	ServerConfig cfg = new ServerConfig();
    	
    	cfg.serverID = server;
    	if (serverSufix != null) {
    		cfg.serverID += serverSufix; 
    	}
    	
    	Server srv = settings.getServer(cfg.serverID);
		if (srv == null) {
            throw new MojoFailureException("You have to configure the server with the id '" + cfg.serverID + "' in your seetings.xml file.");
        }
		Xpp3Dom config = (Xpp3Dom)srv.getConfiguration();
		Xpp3Dom url = config.getChild("url");
		if (url == null) {
            throw new MojoFailureException("You have to configure the server '" + cfg.serverID + "'  configuration url in your seetings.xml file.");
        }
		cfg.url = url.getValue();
		cfg.alias = cfg.serverID + " (" + url.getValue() + ")";
		Xpp3Dom aliasXml = config.getChild("alias");
		if (aliasXml != null) {
			cfg.alias = aliasXml.getValue();
		}
		Xpp3Dom stackXml = config.getChild("stack");
		if (stackXml != null) {
			cfg.stack = stackXml.getValue();
		}
		return cfg;
    }
    
    static void configureBlueCove(ServerConfig cfg, Log log) {
    	if (configured) {
    		return;
    	}
    	configured = true;
    	try {
			BlueCoveSpecific.configureBlueCove(cfg, log);
		} catch (Throwable notBlueCove) {
		}
    }
}
