/**
 * Pyx4me framework
 * Copyright (C) 2006-2007 pyx4.com.
 * 
 * @author vlads
 * @version $Id: BluetoothDiscoveryMojo.java 169 2007-06-29 07:17:19Z vlads $
 */
package com.pyx4me.maven.obex;

import java.io.IOException;
import java.util.Iterator;
import java.util.Vector;

import javax.bluetooth.BluetoothStateException;
import javax.bluetooth.DeviceClass;
import javax.bluetooth.DiscoveryAgent;
import javax.bluetooth.DiscoveryListener;
import javax.bluetooth.LocalDevice;
import javax.bluetooth.RemoteDevice;
import javax.bluetooth.ServiceRecord;

import org.apache.maven.plugin.AbstractMojo;
import org.apache.maven.plugin.MojoExecutionException;
import org.apache.maven.plugin.MojoFailureException;
import org.apache.maven.plugin.logging.Log;
import org.apache.maven.project.MavenProject;

/**
 * The obex:discovery task finds all Bluetooth devices that support OBEX Object Push.
 * 
 * @author vlads
 *
 * @goal discovery
 * @description Find all Bluetooth devices that support OBEX Object Push.
 */
public class BluetoothDiscoveryMojo extends AbstractMojo {

	/**
	 * The Maven project reference where the plugin is currently being executed.
	 * The default value is populated from maven.
	 *
	 * @parameter expression="${project}"
	 * @readonly
	 * @required
	 */
	protected MavenProject mavenProject;
	
	private Log log;
	
	private Vector devices;
	
	private class BluetoothInquirer implements DiscoveryListener {
	    
		boolean inquiring;

	    public boolean startInquiry() {
	    	inquiring = false;
	        try {
	        	inquiring = LocalDevice.getLocalDevice().getDiscoveryAgent().startInquiry(DiscoveryAgent.GIAC, this);
	        } catch (BluetoothStateException e) {
	        	log.error("Cannot start inquiry",  e);
		        return false;
		    }
	        return inquiring;
	    }
	    
        public void deviceDiscovered(RemoteDevice btDevice, DeviceClass cod) {
        	devices.add(btDevice);
            try {
                String name = btDevice.getFriendlyName(false);
                log.info("Found " + btDevice.getBluetoothAddress() + " " + name + " " + DeviceClassConsts.toString(cod));
            } catch(IOException ioe) {
            	log.info("Found " + btDevice.getBluetoothAddress() + " " + DeviceClassConsts.toString(cod));
            }
        }

        public void servicesDiscovered(int transID, ServiceRecord[] servRecord) {
        }

        public void serviceSearchCompleted(int transID, int respCode) {
        }

        public void inquiryCompleted(int discType) {
            inquiring = false;
        }
	    
	}
	
	public void execute() throws MojoExecutionException, MojoFailureException {

		//System.setProperty("bluecove.debug", "true");
		
		log = getLog();
		devices = new Vector();
		
		BluetoothInquirer bi = new BluetoothInquirer();
		log.info("Starting Device inquiry");
		if (!bi.startInquiry()) {
			log.error("Cannot start inquiry");
		} else {
			while (bi.inquiring) {
				try {
					Thread.sleep(1000);
				} catch (Exception e) {
				}
			}
		}
		
		for (Iterator iter = devices.iterator(); iter.hasNext();) {
			RemoteDevice dev = (RemoteDevice) iter.next();
			ServiceSearchMojo.findOBEX(dev.getBluetoothAddress(), null, log);
		}
	}

}
