/**
 * Pyx4me framework
 * Copyright (C) 2006-2007 pyx4.com.
 * 
 * @author vlads
 * @version $Id: ObexDeployMojo.java 187 2007-07-17 17:49:07Z vlads $
 */
package com.pyx4me.maven.obex;

import java.io.File;
import java.util.StringTokenizer;

import org.apache.maven.plugin.MojoExecutionException;
import org.apache.maven.plugin.MojoFailureException;
import org.apache.maven.project.MavenProject;

/**
 * The obex:deploy task execute OBEX PUT to install application.
 * 
 * @author vlads
 *
 * @goal deploy
 * @description Install the *.jar to OBEX Bluetooth enabled phone.
 */
public class ObexDeployMojo extends AbstractDeviceMojo {

    /**
     * The name of the JAR file to deploy. 
     * 
     * @parameter expression="${project.build.finalName}"
     * @required
     */
	protected String jarfile;
	
	/**
     * Retry OBEX connection in case of error. 
     * 
     * @parameter default-value="3"
     */
	protected int connectionRetry;
	
	/**
	 * The Maven project reference where the plugin is currently being executed.
	 * The default value is populated from maven.
	 *
	 * @parameter expression="${project}"
	 * @readonly
	 * @required
	 */
	protected MavenProject mavenProject;
	
	public void execute() throws MojoExecutionException, MojoFailureException {
		File file = new File(mavenProject.getBuild().getDirectory(), jarfile);
		if (!file.exists()) {
			throw new MojoFailureException("Can't find file " + file);
		}
		
		if (serverSufix == null) {
			ObexBluetoothClient.obexPut(file, connectionRetry, getServerConfig(null), getLog());
		} else {
			if (serverSufix.startsWith(",")) {
				ObexBluetoothClient.obexPut(file, connectionRetry,  getServerConfig(null), getLog());	
			}
			StringTokenizer tok = new StringTokenizer(serverSufix, ",");
			while (tok.hasMoreTokens()) {
				ObexBluetoothClient.obexPut(file, connectionRetry, getServerConfig(tok.nextToken()), getLog());
			}
		}
	}
	


}
